Changelog
=========

0.0.19 (development)
--------------------


0.0.18
------
* Update 'gulpfile'
* Update 'readme'
* Update tinymce4 to 4.4.3
* Add 'style_formats' and 'custom_style_formats' js files

0.0.17
------
* Update 'setup.py'
* Publish on pypi use 'pip install django-tinymce-4'

0.0.16
------
* Update to TinyMCE 4.4.1
* Add custom settings files

0.0.15
------
* Add 'example'
* Disable converting urls in "full" settings
* Fix filebrowser error

0.0.14
------
* Add default tinymce content CSS styles
* Add eslint
* Remove unused grappelli and filebrowser js files
* Update to TinyMCE 4.3.4

0.0.13
------
* Update to TinyMCE 4.3.3

0.0.12
------
* Merge css files in __tinymce_4.css

0.0.11
------
* Set RU language by default, add files for custom css

0.0.10
------
* Update to TinyMCE 4.2.6
